<?php
/*
 * $Horde: kronolith/mini_month.php,v 1.8 2001/07/17 10:12:25 avsm Exp $
 *
 * Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

define('KRONOLITH_BASE', dirname(__FILE__));
require_once KRONOLITH_BASE . '/lib/base.php';
require_once KRONOLITH_BASE . '/lib/MonthView.php';

$month = Horde::getFormData('month', '');
$day = Horde::getFormData('day', '');
$year = Horde::getFormData('year', '');
$month = new Kronolith_MonthView($month, $day, $year);
echo $month->html($registry->getTemplatePath());

?>
